==> webHotfixV1.1.0.tar: icpdas/httpd/page/net_port_mapping.php <==

<html>
<head>

<meta content="text/html; charset=UTF-8" http-equiv="content-type">
<title></title>
</head>

<body>
<?php
//====================================
//== get and setting DDNS configure ==
//====================================

require_once("./class.php");

$RULE_NUM = 10;

//-- set Routing configure
if($_POST["submit"]=="Modify")	//press "Modify" button
{
	$j = 0;
	$isOK = true;
	for($i=0; $i<$RULE_NUM; $i++)
	{
		if($_POST["type".$i]=="" && $_POST["from".$i]=="" && $_POST["port".$i]==""
			&& $_POST["to_ip".$i]=="" && $_POST["to_port".$i]=="")
			continue;
		if($_POST["type".$i]!="" && $_POST["from".$i]!="" && $_POST["port".$i]!=""
			&& isIP($_POST["to_ip".$i]) && $_POST["to_port".$i]!="")
		{
			$mapping[$i]["type"] = $_POST["type".$i];
			$mapping[$i]["from"] = $_POST["from".$i];
			$mapping[$i]["port"] = $_POST["port".$i];
			$mapping[$i]["to_ip"] = $_POST["to_ip".$i];
			$mapping[$i]["to_port"] = $_POST["to_port".$i];
		}else
		{
			$isOK = false;
			echo "<div align=\"center\"><font color=\"#cc0000\">Rule $i Configure Error!!</font><br>\n";
		}
	}
	if($isOK)
	{
		setPortMappingCfg($mapping);
		echo "<div align=\"center\"><font color=\"#cc0000\">setting success!!</font><br>\n";
	}
}

//- get Routing Configure
$mapping = NULL;
getPortMappingCfg($mapping);
//print_r($mapping);

?>
	<br>
	<form method="post" name="form1"><br><!-- 加入 action="aa.html" 可以指定給誰處理 -->
		<table align="center" border="1" cellpadding="2" cellspacing="2" width="600">
		<tbody>

		<tr align="center">
			<td colspan="6" bgcolor="#ffcc99">Port Mapping Rule<br></td>
		</tr>

		<tr>
			<td bgcolor="#ccffff" width="100">Rule NO.</td>
			<td bgcolor="#ccffff" width="50">Type</td>
			<td bgcolor="#ccffff" width="100">From</td>
			<td bgcolor="#ccffff" width="100">Port</td>
			<td bgcolor="#ccffff" width="150">Target IP</td>
			<td bgcolor="#ccffff">Target Port</td>
		</tr>

<?php
	$n = count($mapping);
	for($i=0; $i<$RULE_NUM; $i++)
	{
		if($i<$n)
		{
?>
		<tr>
			<td bgcolor="#ccffff"><?php echo $i; ?><br></td>
			<td>
				<select name="<?php echo "type".$i;?>">
				<option value=""></option>
				<option value="tcp" <?php if($mapping[$i]["type"] == "tcp") echo "selected"; ?> >TCP</option>
				<option value="udp" <?php if($mapping[$i]["type"] == "udp") echo "selected"; ?> >UDP</option>
				</select>
			</td>
			<td>
				<select name="<?php echo "from".$i;?>">
				<option value=""></option>
				<option value="ppp0" <?php if($mapping[$i]["from"] == "ppp0") echo "selected"; ?> >ppp0</option>
				</select>
			</td>
			<td><input value="<?php echo $mapping[$i]["port"];?>" name="<?php echo "port".$i;?>" size="10" ></td>
			<td><input value="<?php echo $mapping[$i]["to_ip"];?>" name="<?php echo "to_ip".$i;?>" size="15" ></td>
			<td><input value="<?php echo $mapping[$i]["to_port"];?>" name="<?php echo "to_port".$i;?>" size="10" ></td>
		</tr>
<?php
		}else
		{
?>
		<tr>
			<td bgcolor="#ccffff"><?php echo $i; ?><br></td>
			<td>
				<select name="<?php echo "type".$i;?>">
				<option value="" selected></option>
				<option value="tcp">TCP</option>
				<option value="udp">UDP</option>
				</select>
			</td>
			<td>
				<select name="<?php echo "from".$i;?>">
				<option value=""></option>
				<option value="ppp0" <?php if($mapping[$i]["from"] == "ppp0") echo "selected"; ?> >ppp0</option>
				</select>
			</td>
			<td><input value="" name="<?php echo "port".$i;?>" size="10" ></td>
			<td><input value="" name="<?php echo "to_ip".$i;?>" size="15" ></td>
			<td><input value="" name="<?php echo "to_port".$i;?>" size="10" ></td>
		</tr>
<?php
		}
	}
?>

		<tr align="center">
			<td colspan="6"><input name="submit" value="Modify" type="submit"><br>
			</td>
		</tr>

		</tbody>
		</table>

		<br>
		<br>
	</form>
	<br>
	<br>

</body></html>

==> webHotfixV1.3.0_2015-08-25.tar: icpdas/httpd/page/net_port_mapping.php <==

<html>
<head>

<meta content="text/html; charset=UTF-8" http-equiv="content-type">
<title></title>
</head>

<body>
<?php
//====================================
//== get and setting DDNS configure ==
//====================================

require_once("./class.php");

$RULE_NUM = 10;

//-- set Routing configure
if($_POST["submit"]=="Modify")	//press "Modify" button
{
	$j = 0;
	$isOK = true;
	for($i=0; $i<$RULE_NUM; $i++)
	{
		if($_POST["type".$i]=="" && $_POST["from".$i]=="" && $_POST["port".$i]==""
			&& $_POST["to_ip".$i]=="" && $_POST["to_port".$i]=="")
			continue;
		if($_POST["type".$i]!="" && $_POST["from".$i]!="" && $_POST["port".$i]!=""
			&& isIP($_POST["to_ip".$i]) && $_POST["to_port".$i]!="")
		{
			$mapping[$i]["type"] = $_POST["type".$i];
			$mapping[$i]["from"] = $_POST["from".$i];
			$mapping[$i]["port"] = $_POST["port".$i];
			$mapping[$i]["to_ip"] = $_POST["to_ip".$i];
			$mapping[$i]["to_port"] = $_POST["to_port".$i];
		}else
		{
			$isOK = false;
			echo "<div align=\"center\"><font color=\"#cc0000\">Rule $i Configure Error!!</font><br>\n";
		}
	}
	if($isOK)
	{
		setPortMappingCfg($mapping);
		echo "<div align=\"center\"><font color=\"#cc0000\">setting success!!</font><br>\n";
	}
}

//- get Routing Configure
$mapping = NULL;
getPortMappingCfg($mapping);
//print_r($mapping);

?>
	<br>
	<form method="post" name="form1"><br><!-- 加入 action="aa.html" 可以指定給誰處理 -->
		<table align="center" border="1" cellpadding="2" cellspacing="2" width="600">
		<tbody>

		<tr align="center">
			<td colspan="6" bgcolor="#ffcc99">Port Mapping Rule<br></td>
		</tr>

		<tr>
			<td bgcolor="#ccffff" width="100">Rule NO.</td>
			<td bgcolor="#ccffff" width="50">Type</td>
			<td bgcolor="#ccffff" width="100">From</td>
			<td bgcolor="#ccffff" width="100">Port</td>
			<td bgcolor="#ccffff" width="150">Target IP</td>
			<td bgcolor="#ccffff">Target Port</td>
		</tr>

<?php
	$n = count($mapping);
	for($i=0; $i<$RULE_NUM; $i++)
	{
		if($i<$n)
		{
?>
		<tr>
			<td bgcolor="#ccffff"><?php echo $i; ?><br></td>
			<td>
				<select name="<?php echo "type".$i;?>">
				<option value=""></option>
				<option value="tcp" <?php if($mapping[$i]["type"] == "tcp") echo "selected"; ?> >TCP</option>
				<option value="udp" <?php if($mapping[$i]["type"] == "udp") echo "selected"; ?> >UDP</option>
				</select>
			</td>
			<td>
				<select name="<?php echo "from".$i;?>">
				<option value=""></option>
				<option value="ppp0" <?php if($mapping[$i]["from"] == "ppp0") echo "selected"; ?> >ppp0</option>
				<option value="ppp1" <?php if($mapping[$i]["from"] == "ppp1") echo "selected"; ?> >ppp1</option>
				</select>
			</td>
			<td><input value="<?php echo $mapping[$i]["port"];?>" name="<?php echo "port".$i;?>" size="10" ></td>
			<td><input value="<?php echo $mapping[$i]["to_ip"];?>" name="<?php echo "to_ip".$i;?>" size="15" ></td>
			<td><input value="<?php echo $mapping[$i]["to_port"];?>" name="<?php echo "to_port".$i;?>" size="10" ></td>
		</tr>
<?php
		}else
		{
?>
		<tr>
			<td bgcolor="#ccffff"><?php echo $i; ?><br></td>
			<td>
				<select name="<?php echo "type".$i;?>">
				<option value="" selected></option>
				<option value="tcp">TCP</option>
				<option value="udp">UDP</option>
				</select>
			</td>
			<td>
				<select name="<?php echo "from".$i;?>">
				<option value=""></option>
				<option value="ppp0" <?php if($mapping[$i]["from"] == "ppp0") echo "selected"; ?> >ppp0</option>
				<option value="ppp1" <?php if($mapping[$i]["from"] == "ppp1") echo "selected"; ?> >ppp1</option>
				</select>
			</td>
			<td><input value="" name="<?php echo "port".$i;?>" size="10" ></td>
			<td><input value="" name="<?php echo "to_ip".$i;?>" size="15" ></td>
			<td><input value="" name="<?php echo "to_port".$i;?>" size="10" ></td>
		</tr>
<?php
		}
	}
?>

		<tr align="center">
			<td colspan="6"><input name="submit" value="Modify" type="submit"><br>
			</td>
		</tr>

		</tbody>
		</table>

		<br>
		<br>
	</form>
	<br>
	<br>

</body></html>
